@@ -102,6 +102,7 @@ CommandMap cmdMap[] =
   { "$",             CMD_DOLLAR },
   { "#",             CMD_HASH },
   { "%",             CMD_PERCENT },
+  { "::",            CMD_DCOLON },
   { "\"",            CMD_QUOTE },
   { "_internalref",  CMD_INTERNALREF },
   { "dot",           CMD_DOT },
@@ -112,7 +113,8 @@ CommandMap cmdMap[] =
   { "endmanonly",    CMD_ENDMANONLY },
   { "includelineno", CMD_INCWITHLINES },
   { "inheritdoc",    CMD_INHERITDOC },
-  { 0,               0 }
+  { "mscfile",       CMD_MSCFILE },
+  { 0,               0 },
 };
 
 //----------------------------------------------------------------------------
