@@ -2,7 +2,7 @@
  *
  * $Id: declinfo.h,v 1.1 1998/09/09 21:32:19 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -23,6 +23,7 @@
 
 class ArgumentList;
 
-extern void stringToArgumentList(const char *argsString,ArgumentList* &argList);
+extern void stringToArgumentList(const char *argsString,ArgumentList* argList,
+                                 QCString *extraTypeChars=0);
 
 #endif
