@@ -3,7 +3,7 @@
  * $Id: def.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -35,7 +35,7 @@
 
 #define DEF_DB(x)
 
-inline void writeDEFString(QTextStream &t,const char *s)
+inline void writeDEFString(FTextStream &t,const char *s)
 {
   const char* p=s;
   char c;
@@ -51,7 +51,7 @@ inline void writeDEFString(QTextStream &t,const char *s)
 }
 
 void generateDEFForMember(MemberDef *md,
-    QTextStream &t,
+    FTextStream &t,
     Definition *def,
     const char* Prefix)
 {
@@ -94,7 +94,6 @@ void generateDEFForMember(MemberDef *md,
     case MemberDef::Enumeration: memType="enum";      break;
     case MemberDef::Function:    memType="function";  isFunc=TRUE; break;
     case MemberDef::Signal:      memType="signal";    isFunc=TRUE; break;
-    case MemberDef::Prototype:   memType="prototype"; isFunc=TRUE; break;
     case MemberDef::Friend:      memType="friend";    isFunc=TRUE; break;
     case MemberDef::DCOP:        memType="dcop";      isFunc=TRUE; break;
     case MemberDef::Slot:        memType="slot";      isFunc=TRUE; break;
@@ -313,7 +312,7 @@ void generateDEFForMember(MemberDef *md,
 
 
 void generateDEFClassSection(ClassDef *cd,
-    QTextStream &t,
+    FTextStream &t,
     MemberList *ml,
     const char *kind)
 {
@@ -332,7 +331,7 @@ void generateDEFClassSection(ClassDef *cd,
   }
 }
 
-void generateDEFForClass(ClassDef *cd,QTextStream &t)
+void generateDEFForClass(ClassDef *cd,FTextStream &t)
 {
   // + brief description
   // + detailed description
@@ -475,7 +474,7 @@ void generateDEFForClass(ClassDef *cd,QTextStream &t)
 }
 
 void generateDEFSection(Definition *d,
-    QTextStream &t,
+    FTextStream &t,
     MemberList *ml,
     const char *kind)
 {
@@ -492,7 +491,7 @@ void generateDEFSection(Definition *d,
   }
 }
 
-void generateDEFForNamespace(NamespaceDef *nd,QTextStream &t)
+void generateDEFForNamespace(NamespaceDef *nd,FTextStream &t)
 {
   if (nd->isReference()) return; // skip external references
   t << "  namespace = {" << endl;
@@ -518,7 +517,7 @@ void generateDEFForNamespace(NamespaceDef *nd,QTextStream &t)
   t << "  };" << endl;
 }
 
-void generateDEFForFile(FileDef *fd,QTextStream &t)
+void generateDEFForFile(FileDef *fd,FTextStream &t)
 {
   if (fd->isReference()) return; // skip external references
 
@@ -563,13 +562,13 @@ void generateDEF()
       dir.setPath(QDir::currentDirPath());
       if (!dir.mkdir(outputDirectory))
       {
-        err("Error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
+        err("error: tag OUTPUT_DIRECTORY: Output directory `%s' does not "
             "exist and cannot be created\n",outputDirectory.data());
         exit(1);
       }
       else if (!Config_getBool("QUIET"))
       {
-        err("Notice: Output directory `%s' does not exist. "
+        err("notice: Output directory `%s' does not exist. "
             "I have created it for you.\n", outputDirectory.data());
       }
       dir.cd(outputDirectory);
@@ -601,7 +600,7 @@ void generateDEF()
     err("Cannot open file %s for writing!\n",fileName.data());
     return;
   }
-  QTextStream t(&f);
+  FTextStream t(&f);
   t << "AutoGen Definitions dummy;" << endl;
 
   if (Doxygen::classSDict->count()+Doxygen::inputNameList->count()>0)
