@@ -2,7 +2,7 @@
  *
  * $Id: define.cpp,v 1.7 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,8 +20,11 @@
 
 Define::Define()
 { 
-  undef=FALSE; 
   fileDef=0; 
+  lineNr=1;
+  nargs=-1;
+  undef=FALSE; 
+  varArgs=FALSE;
   isPredefined=FALSE;
   nonRecursive=FALSE;
 }
@@ -33,6 +36,9 @@ Define::Define(const Define &d)
   lineNr=d.lineNr; 
   nargs=d.nargs; 
   undef=d.undef; 
+  varArgs=d.varArgs;
+  isPredefined=d.isPredefined;
+  nonRecursive=d.nonRecursive;
   fileDef=0;
 }
 
