@@ -8,7 +8,6 @@
 "/* @group Heading Levels */\n"
 "\n"
 "h1 {\n"
-"	text-align: center;\n"
 "	font-size: 150%;\n"
 "}\n"
 "\n"
@@ -64,8 +63,8 @@
 "}\n"
 "\n"
 "div.qindex, div.navtab{\n"
-"	background-color: #e8eef2;\n"
-"	border: 1px solid #84b0c7;\n"
+"	background-color: ##ee;\n"
+"	border: 1px solid ##b0;\n"
 "	text-align: center;\n"
 "	margin: 2px;\n"
 "	padding: 2px;\n"
@@ -83,13 +82,13 @@
 "/* @group Link Styling */\n"
 "\n"
 "a {\n"
-"	color: #153788;\n"
+"	color: ##50;\n"
 "	font-weight: normal;\n"
 "	text-decoration: none;\n"
 "}\n"
 "\n"
 ".contents a:visited {\n"
-"	color: #1b77c5;\n"
+"	color: ##60;\n"
 "}\n"
 "\n"
 "a:hover {\n"
@@ -102,9 +101,9 @@
 "\n"
 "a.qindexHL {\n"
 "	font-weight: bold;\n"
-"	background-color: #6666cc;\n"
+"	background-color: ##AA;\n"
 "	color: #ffffff;\n"
-"	border: 1px double #9295C2;\n"
+"	border: 1px double ##98;\n"
 "}\n"
 "\n"
 ".contents a.qindexHL:visited {\n"
@@ -119,11 +118,11 @@
 "}\n"
 "\n"
 "a.code {\n"
-"	color: #3030f0;\n"
+"	color: ##60;\n"
 "}\n"
 "\n"
 "a.codeRef {\n"
-"	color: #3030f0;\n"
+"	color: ##60;\n"
 "}\n"
 "\n"
 "/* @end */\n"
@@ -138,8 +137,8 @@
 "}\n"
 "\n"
 "pre.fragment {\n"
-"	border: 1px solid #CCCCCC;\n"
-"	background-color: #f5f5f5;\n"
+"	border: 1px solid ##CC;\n"
+"	background-color: ##FC;\n"
 "	padding: 4px 6px;\n"
 "	margin: 4px 8px 4px 2px;\n"
 "	overflow: auto;\n"
@@ -153,13 +152,22 @@
 "	font-weight: bold;\n"
 "	color: #ffffff;\n"
 "	margin-bottom: 3px;\n"
-"	margin-top: 3px\n"
+"	margin-top: 3px;\n"
+"	padding: 0.2em;\n"
+"	border: solid thin #333;\n"
+"	border-radius: 0.5em;\n"
+"	-webkit-border-radius: .5em;\n"
+"	-moz-border-radius: .5em;\n"
+"	box-shadow: 2px 2px 3px #999;\n"
+"	-webkit-box-shadow: 2px 2px 3px #999;\n"
+"	-moz-box-shadow: rgba(0, 0, 0, 0.15) 2px 2px 2px;\n"
+"	background-image: -webkit-gradient(linear, left top, left bottom, from(#eee), to(#000),color-stop(0.3, #444));\n"
+"	background-image: -moz-linear-gradient(center top, #eee 0%, #444 40%, #000);\n"
 "}\n"
 "\n"
 "div.groupHeader {\n"
 "	margin-left: 16px;\n"
 "	margin-top: 12px;\n"
-"	margin-bottom: 6px;\n"
 "	font-weight: bold;\n"
 "}\n"
 "\n"
@@ -171,27 +179,32 @@
 "body {\n"
 "	background: white;\n"
 "	color: black;\n"
-"	margin-right: 20px;\n"
-"	margin-left: 20px;\n"
+"        margin: 0;\n"
+"}\n"
+"\n"
+"div.contents {\n"
+"	margin-top: 10px;\n"
+"	margin-left: 10px;\n"
+"	margin-right: 10px;\n"
 "}\n"
 "\n"
 "td.indexkey {\n"
-"	background-color: #e8eef2;\n"
+"	background-color: ##ee;\n"
 "	font-weight: bold;\n"
-"	border: 1px solid #CCCCCC;\n"
+"	border: 1px solid ##cc;\n"
 "	margin: 2px 0px 2px 0;\n"
 "	padding: 2px 10px;\n"
 "}\n"
 "\n"
 "td.indexvalue {\n"
-"	background-color: #e8eef2;\n"
-"	border: 1px solid #CCCCCC;\n"
+"	background-color: ##ee;\n"
+"	border: 1px solid ##cc;\n"
 "	padding: 2px 10px;\n"
 "	margin: 2px 0px;\n"
 "}\n"
 "\n"
 "tr.memlist {\n"
-"	background-color: #f0f0f0;\n"
+"	background-color: ##f0;\n"
 "}\n"
 "\n"
 "p.formulaDsp {\n"
@@ -217,6 +230,11 @@
 "	border: 0px;\n"
 "}\n"
 "\n"
+"address.footer {\n"
+"	text-align: right;\n"
+"	padding-right: 12px;\n"
+"}\n"
+"\n"
 "img.footer {\n"
 "	border: 0px;\n"
 "	vertical-align: middle;\n"
@@ -270,6 +288,7 @@
 "\n"
 "/* @end */\n"
 "\n"
+"/*\n"
 ".search {\n"
 "	color: #003399;\n"
 "	font-weight: bold;\n"
@@ -286,6 +305,7 @@
 "	font-weight: normal;\n"
 "	background-color: #e8eef2;\n"
 "}\n"
+"*/\n"
 "\n"
 "td.tiny {\n"
 "	font-size: 75%;\n"
@@ -294,18 +314,18 @@
 ".dirtab {\n"
 "	padding: 4px;\n"
 "	border-collapse: collapse;\n"
-"	border: 1px solid #84b0c7;\n"
+"	border: 1px solid ##b0;\n"
 "}\n"
 "\n"
 "th.dirtab {\n"
-"	background: #e8eef2;\n"
+"	background: ##ee;\n"
 "	font-weight: bold;\n"
 "}\n"
 "\n"
 "hr {\n"
 "	height: 0px;\n"
 "	border: none;\n"
-"	border-top: 1px solid #666;\n"
+"	border-top: 1px solid ##66;\n"
 "}\n"
 "\n"
 "hr.footer {\n"
@@ -314,10 +334,15 @@
 "\n"
 "/* @group Member Descriptions */\n"
 "\n"
+"table.memberdecls {\n"
+"	border-spacing: 0px;\n"
+"	padding: 0px;\n"
+"}\n"
+"\n"
 ".mdescLeft, .mdescRight,\n"
 ".memItemLeft, .memItemRight,\n"
 ".memTemplItemLeft, .memTemplItemRight, .memTemplParams {\n"
-"	background-color: #FAFAFA;\n"
+"	background-color: ##FA;\n"
 "	border: none;\n"
 "	margin: 4px;\n"
 "	padding: 1px 0 0 8px;\n"
@@ -329,7 +354,7 @@
 "}\n"
 "\n"
 ".memItemLeft, .memItemRight, .memTemplParams {\n"
-"	border-top: 1px solid #ccc;\n"
+"	border-top: 1px solid ##cc;\n"
 "}\n"
 "\n"
 ".memItemLeft, .memTemplItemLeft {\n"
@@ -337,7 +362,7 @@
 "}\n"
 "\n"
 ".memTemplParams {\n"
-"	color: #606060;\n"
+"	color: ##60;\n"
 "        white-space: nowrap;\n"
 "}\n"
 "\n"
@@ -349,14 +374,14 @@
 "\n"
 ".memtemplate {\n"
 "	font-size: 80%;\n"
-"	color: #606060;\n"
+"	color: ##60;\n"
 "	font-weight: normal;\n"
-"	margin-left: 3px;\n"
+"	margin-left: 9px;\n"
 "}\n"
 "\n"
 ".memnav {\n"
-"	background-color: #e8eef2;\n"
-"	border: 1px solid #84b0c7;\n"
+"	background-color: ##ee;\n"
+"	border: 1px solid ##b0;\n"
 "	text-align: center;\n"
 "	margin: 2px;\n"
 "	margin-right: 15px;\n"
@@ -375,40 +400,52 @@
 "}\n"
 "\n"
 ".memproto {\n"
-"        border-top: 1px solid #84b0c7;          \n"
-"        border-left: 1px solid #84b0c7;         \n"
-"        border-right: 1px solid #84b0c7; \n"
-"        padding: 0;\n"
-"        background-color: #d5e1e8;\n"
+"        border-top: 1px solid ##B4;\n"
+"        border-left: 1px solid ##B4;\n"
+"        border-right: 1px solid ##B4;\n"
+"        padding: 6px 0px 6px 0px;\n"
+"        color: ##2b;\n"
 "        font-weight: bold;\n"
+"        text-shadow: 0px 1px 1px rgba(255, 255, 255, 0.9);\n"
+"        /* opera specific markup */\n"
+"        box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
+"        border-top-right-radius: 8px;\n"
+"        border-top-left-radius: 8px;\n"
 "        /* firefox specific markup */\n"
-"        background-image: -moz-linear-gradient(rgba(228, 233, 245, 1.0) 0%, rgba(193, 205, 232, 1.0) 100%);\n"
 "        -moz-box-shadow: rgba(0, 0, 0, 0.15) 5px 5px 5px;\n"
 "        -moz-border-radius-topright: 8px;\n"
 "        -moz-border-radius-topleft: 8px;\n"
 "        /* webkit specific markup */\n"
-"        background-image: -webkit-gradient(linear, 0% 0%, 0% 100%, from(rgba(228, 233, 245, 1.0)), to(rgba(193, 205, 232, 1.0)));\n"
 "        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
 "        -webkit-border-top-right-radius: 8px;\n"
 "        -webkit-border-top-left-radius: 8px;\n"
+"        background-image:url('nav_f.png');\n"
+"        background-repeat:repeat-x;\n"
+"        background-color: ##E6;\n"
 "\n"
 "}\n"
 "\n"
 ".memdoc {\n"
-"        border-bottom: 1px solid #84b0c7;      \n"
-"        border-left: 1px solid #84b0c7;      \n"
-"        border-right: 1px solid #84b0c7; \n"
+"        border-bottom: 1px solid ##B4;      \n"
+"        border-left: 1px solid ##B4;      \n"
+"        border-right: 1px solid ##B4; \n"
 "        padding: 2px 5px;\n"
-"        background-color: #eef3f5;\n"
+"        background-color: ##FC;\n"
 "        border-top-width: 0;\n"
+"        /* opera specific markup */\n"
+"        border-bottom-left-radius: 8px;\n"
+"        border-bottom-right-radius: 8px;\n"
+"        box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
 "        /* firefox specific markup */\n"
 "        -moz-border-radius-bottomleft: 8px;\n"
 "        -moz-border-radius-bottomright: 8px;\n"
 "        -moz-box-shadow: rgba(0, 0, 0, 0.15) 5px 5px 5px;\n"
+"        background-image: -moz-linear-gradient(center top, ##FF 0%, ##FF 60%, ##F8 95%, ##F0);\n"
 "        /* webkit specific markup */\n"
 "        -webkit-border-bottom-left-radius: 8px;\n"
 "        -webkit-border-bottom-right-radius: 8px;\n"
 "        -webkit-box-shadow: 5px 5px 5px rgba(0, 0, 0, 0.15);\n"
+"        background-image: -webkit-gradient(linear,center top,center bottom,from(##FF), color-stop(0.6,##FF), color-stop(0.60,##FF), color-stop(0.95,##F8), to(##F0));\n"
 "}\n"
 "\n"
 ".paramkey {\n"
@@ -427,6 +464,28 @@
 "	font-style: normal;\n"
 "}\n"
 "\n"
+".params, .retval, .exception, .tparams {\n"
+"        border-spacing: 6px 2px;\n"
+"}       \n"
+"\n"
+".params .paramname, .retval .paramname {\n"
+"        font-weight: bold;\n"
+"        vertical-align: top;\n"
+"}\n"
+"        \n"
+".params .paramtype {\n"
+"        font-style: italic;\n"
+"        vertical-align: top;\n"
+"}       \n"
+"        \n"
+".params .paramdir {\n"
+"        font-family: \"courier new\",courier,monospace;\n"
+"        vertical-align: top;\n"
+"}\n"
+"\n"
+"\n"
+"\n"
+"\n"
 "/* @end */\n"
 "\n"
 "/* @group Directory (tree) */\n"
@@ -435,7 +494,7 @@
 "\n"
 ".ftvtree {\n"
 "	font-family: sans-serif;\n"
-"	margin: 0.5em;\n"
+"	margin: 0px;\n"
 "}\n"
 "\n"
 "/* these are for tree view when used as main index */\n"
@@ -443,6 +502,7 @@
 ".directory {\n"
 "	font-size: 9pt;\n"
 "	font-weight: bold;\n"
+"	margin: 5px;\n"
 "}\n"
 "\n"
 ".directory h3 {\n"
@@ -520,9 +580,13 @@
 "\n"
 "/* @end */\n"
 "\n"
+"div.dynheader {\n"
+"        margin-top: 8px;\n"
+"}\n"
+"\n"
 "address {\n"
 "	font-style: normal;\n"
-"	color: #333;\n"
+"	color: ##33;\n"
 "}\n"
 "\n"
 "table.doxtable {\n"
@@ -530,12 +594,12 @@
 "}\n"
 "\n"
 "table.doxtable td, table.doxtable th {\n"
-"	border: 1px solid #153788;\n"
+"	border: 1px solid ##37;\n"
 "	padding: 3px 7px 2px;\n"
 "}\n"
 "\n"
 "table.doxtable th {\n"
-"	background-color: #254798;\n"
+"	background-color: ##47;\n"
 "	color: #FFFFFF;\n"
 "	font-size: 110%;\n"
 "	padding-bottom: 4px;\n"
@@ -543,3 +607,194 @@
 "	text-align:left;\n"
 "}\n"
 "\n"
+".tabsearch {\n"
+"	top: 0px;\n"
+"	left: 10px;\n"
+"	height: 36px;\n"
+"	background-image: url('tab_b.png');\n"
+"	z-index: 101;\n"
+"	overflow: hidden;\n"
+"	font-size: 13px;\n"
+"}\n"
+"\n"
+".navpath ul\n"
+"{\n"
+"	font-size: 11px;\n"
+"	background-image:url('tab_b.png');\n"
+"	background-repeat:repeat-x;\n"
+"	height:30px;\n"
+"	line-height:30px;\n"
+"	color:##9b;\n"
+"	border:solid 1px ##ca;\n"
+"	overflow:hidden;\n"
+"	margin:0px;\n"
+"	padding:0px;\n"
+"}\n"
+"\n"
+".navpath li\n"
+"{\n"
+"	list-style-type:none;\n"
+"	float:left;\n"
+"	padding-left:10px;\n"
+"	padding-right:15px;\n"
+"	background-image:url('bc_s.png');\n"
+"	background-repeat:no-repeat;\n"
+"	background-position:right;\n"
+"	color:##45;\n"
+"}\n"
+"\n"
+".navpath li.navelem a\n"
+"{\n"
+"	height:32px;\n"
+"	display:block;\n"
+"	text-decoration: none;\n"
+"	outline: none;\n"
+"}\n"
+"\n"
+".navpath li.navelem a:hover\n"
+"{\n"
+"	color:##80;\n"
+"}\n"
+"\n"
+".navpath li.footer\n"
+"{\n"
+"        list-style-type:none;\n"
+"        float:right;\n"
+"        padding-left:10px;\n"
+"        padding-right:15px;\n"
+"        background-image:none;\n"
+"        background-repeat:no-repeat;\n"
+"        background-position:right;\n"
+"        color:##45;\n"
+"        font-size: 8pt;\n"
+"}\n"
+"\n"
+"\n"
+"div.summary\n"
+"{\n"
+"	float: right;\n"
+"	font-size: 8pt;\n"
+"	padding-right: 5px;\n"
+"	width: 50%;\n"
+"	text-align: right;\n"
+"}       \n"
+"\n"
+"div.summary a\n"
+"{\n"
+"	white-space: nowrap;\n"
+"}\n"
+"\n"
+"div.ingroups\n"
+"{\n"
+"	font-size: 8pt;\n"
+"	padding-left: 5px;\n"
+"	width: 50%;\n"
+"	text-align: left;\n"
+"}\n"
+"\n"
+"div.ingroups a\n"
+"{\n"
+"	white-space: nowrap;\n"
+"}\n"
+"\n"
+"div.header\n"
+"{\n"
+"        background-image:url('nav_h.png');\n"
+"        background-repeat:repeat-x;\n"
+"	background-color: ##FA;\n"
+"	margin:  0px;\n"
+"	border-bottom: 1px solid ##CC;\n"
+"}\n"
+"\n"
+"div.headertitle\n"
+"{\n"
+"	padding: 5px 5px 5px 10px;\n"
+"}\n"
+"\n"
+"dl\n"
+"{\n"
+"        padding: 0 0 0 10px;\n"
+"}\n"
+"\n"
+"dl.note, dl.warning, dl.attention, dl.pre, dl.post, dl.invariant, dl.deprecated, dl.todo, dl.test, dl.bug\n"
+"{\n"
+"        border-left:4px solid;\n"
+"        padding: 0 0 0 6px;\n"
+"}\n"
+"\n"
+"dl.note\n"
+"{\n"
+"        border-color: #D0D000;\n"
+"}\n"
+"\n"
+"dl.warning, dl.attention\n"
+"{\n"
+"        border-color: #FF0000;\n"
+"}\n"
+"\n"
+"dl.pre, dl.post, dl.invariant\n"
+"{\n"
+"        border-color: #00D000;\n"
+"}\n"
+"\n"
+"dl.deprecated\n"
+"{\n"
+"        border-color: #505050;\n"
+"}\n"
+"\n"
+"dl.todo\n"
+"{\n"
+"        border-color: #00C0E0;\n"
+"}\n"
+"\n"
+"dl.test\n"
+"{\n"
+"        border-color: #3030E0;\n"
+"}\n"
+"\n"
+"dl.bug\n"
+"{\n"
+"        border-color: #C08050;\n"
+"}\n"
+"\n"
+"#projectlogo\n"
+"{\n"
+"	text-align: center;\n"
+"	vertical-align: bottom;\n"
+"	border-collapse: separate;\n"
+"}\n"
+" \n"
+"#projectlogo img\n"
+"{ \n"
+"	border: 0px none;\n"
+"}\n"
+" \n"
+"#projectname\n"
+"{\n"
+"	font: 300% arial,sans-serif;\n"
+"	margin: 0px;\n"
+"	padding: 0px;\n"
+"}\n"
+"    \n"
+"#projectbrief\n"
+"{\n"
+"	font: 120% arial,sans-serif;\n"
+"	margin: 0px;\n"
+"	padding: 0px;\n"
+"}\n"
+"\n"
+"#projectnumber\n"
+"{\n"
+"	font: 50% arial,sans-serif;\n"
+"	margin: 0px;\n"
+"	padding: 0px;\n"
+"}\n"
+"\n"
+"#titlearea\n"
+"{\n"
+"	padding: 0px;\n"
+"	margin: 0px;\n"
+"	width: 100%;\n"
+"	border-bottom: 1px solid ##70;\n"
+"}\n"
+"\n"
