@@ -409,12 +409,12 @@ void MemberList::writeDeclarations(OutputList &ol,
   if (numDecMembers()==0) return;
   //printf("%p: MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",
   //    this,title,subtitle,numDecMembers());
+  ol.startMemberHeader(listTypeAsString());
   if (title) 
   {
-    ol.startMemberHeader(listTypeAsString());
     ol.parseText(title);
-    ol.endMemberHeader();
   }
+  ol.endMemberHeader();
   if (subtitle) 
   {
     QCString st=subtitle;
@@ -422,7 +422,7 @@ void MemberList::writeDeclarations(OutputList &ol,
     if (!st.isEmpty())
     {
       ol.startMemberSubtitle();
-      ol.parseDoc("[generated]",-1,ctx,0,subtitle,FALSE,FALSE);
+      ol.parseDoc("[generated]",-1,ctx,0,subtitle,FALSE,FALSE,0,TRUE,FALSE);
       ol.endMemberSubtitle();
     }
   }
@@ -449,8 +449,8 @@ void MemberList::writeDeclarations(OutputList &ol,
     MemberGroup *mg;
     while ((mg=mgli.current()))
     {
-      //printf("mg->header=%s\n",mg->header().data());
-      bool hasHeader=mg->header()!="[NOHEADER]";
+      bool hasHeader=!mg->header().isEmpty() && mg->header()!="[NOHEADER]";
+      //printf("mg->header=%s hasHeader=%d\n",mg->header().data(),hasHeader);
       ol.startMemberGroupHeader(hasHeader);
       if (hasHeader)
       {
@@ -515,14 +515,19 @@ void MemberList::writeDocumentation(OutputList &ol,
 void MemberList::writeDocumentationPage(OutputList &ol,
                      const char *scopeName, Definition *container)
 {
+  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
   MemberListIterator mli(*this);
   MemberDef *md;
   for ( ; (md=mli.current()) ; ++mli)
   {
     QCString diskName=md->getOutputFileBase();
     QCString title=md->qualifiedName();
-    startFile(ol,diskName,md->name(),title);
-    container->writeNavigationPath(ol);
+    startFile(ol,diskName,md->name(),title,HLI_None,!generateTreeView,
+              container->getOutputFileBase());
+    if (!generateTreeView)
+    {
+      container->writeNavigationPath(ol);
+    }
     ol.startContents();
 
     ol.writeString("<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n"
@@ -539,8 +544,15 @@ void MemberList::writeDocumentationPage(OutputList &ol,
     ol.writeString("    </td>\n");
     ol.writeString("  </tr>\n");
     ol.writeString("</table>\n");
-    
-    endFile(ol);
+
+    ol.endContents();
+
+    if (generateTreeView)
+    {
+      container->writeNavigationPath(ol);
+    }
+
+    endFile(ol,TRUE);
   }
   if (memberGroupList)
   {
