@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2010 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -83,6 +83,8 @@ class PrintDocVisitor : public DocVisitor
 	case DocSymbol::Cedil:   printf("&%ccedul;",s->letter()); break;
 	case DocSymbol::Ring:    printf("&%cring;",s->letter()); break;
 	case DocSymbol::Nbsp:    printf("&nbsp;"); break;
+	case DocSymbol::Aelig:   printf("&aelig;"); break;
+	case DocSymbol::AElig:   printf("&AElig;"); break;
 	default:
 	  printf("Error: unknown symbol found\n");
       }
@@ -208,6 +210,11 @@ class PrintDocVisitor : public DocVisitor
       indent_leaf();
       printf("<indexentry>%s</indexentry\n",i->entry().data());
     }
+    void visit(DocSimpleSectSep *)
+    {
+      indent_leaf();
+      printf("<simplesectsep/>");
+    }
 
     //--------------------------------------
     
@@ -496,6 +503,16 @@ class PrintDocVisitor : public DocVisitor
       indent_post();
       printf("</dotfile>\n");
     }
+    void visitPre(DocMscFile *df)
+    {
+      indent_pre();
+      printf("<mscfile src=\"%s\">\n",df->name().data());
+    }
+    void visitPost(DocMscFile *) 
+    {
+      indent_post();
+      printf("</mscfile>\n");
+    }
     void visitPre(DocLink *lnk)
     {
       indent_pre();
