@@ -238,13 +238,13 @@
 "      if (child.className=='SelectItem')\n"
 "      {\n"
 "        var node = child.firstChild;\n"
-"	if (j==id)\n"
-"	{\n"
+"        if (j==id)\n"
+"        {\n"
 "          node.innerHTML='&bull;';\n"
-"        } \n"
+"        }\n"
 "        else\n"
 "        {\n"
-"          node.innerHTML='&nbsp;';\n"
+"          node.innerHTML='&#160;';\n"
 "        }\n"
 "        j++;\n"
 "      }\n"
@@ -324,7 +324,7 @@
 "    var resultsPageWithSearch;\n"
 "    var hasResultsPage;\n"
 "\n"
-"    if (indexSectionsWithContent[this.searchIndex].charAt(code-32) == '1')\n"
+"    if (indexSectionsWithContent[this.searchIndex].charAt(code) == '1')\n"
 "    {\n"
 "       resultsPage = this.resultsPath + '/' + indexSectionNames[this.searchIndex] + '_' + hexCode + '.html';\n"
 "       resultsPageWithSearch = resultsPage+'?'+escape(searchValue);\n"
@@ -356,8 +356,8 @@
 "       else\n"
 "       {\n"
 "         var domPopupSearchResults = this.DOMPopupSearchResults();\n"
-"         var left = getXPos(domSearchBox) + domSearchBox.offsetWidth;\n"
-"         var top  = getYPos(domSearchBox) + domSearchBox.offsetHeight + 1;\n"
+"         var left = getXPos(domSearchBox) + 150; // domSearchBox.offsetWidth;\n"
+"         var top  = getYPos(domSearchBox) + 20;  // domSearchBox.offsetHeight + 1;\n"
 "         domPopupSearchResultsWindow.style.display = 'block';\n"
 "         left -= domPopupSearchResults.offsetWidth;\n"
 "         domPopupSearchResultsWindow.style.top     = top  + 'px';\n"
@@ -453,20 +453,20 @@
 "      if (element)\n"
 "      {\n"
 "        if (element.style.display == 'block')\n"
-"        {  \n"
-"          element.style.display = 'none';  \n"
+"        {\n"
+"          element.style.display = 'none';\n"
 "        }\n"
 "        else\n"
-"        {  \n"
-"          element.style.display = 'block';  \n"
+"        {\n"
+"          element.style.display = 'block';\n"
 "        }\n"
 "      }\n"
 "    }\n"
 "\n"
-"    // Searches for the passed string.  If there is no parameter, \n"
+"    // Searches for the passed string.  If there is no parameter,\n"
 "    // it takes it from the URL query.\n"
 "    //\n"
-"    // Always returns true, since other documents may try to call it \n"
+"    // Always returns true, since other documents may try to call it\n"
 "    // and that may or may not be possible.\n"
 "    this.Search = function(search)\n"
 "    {\n"
@@ -501,20 +501,20 @@
 "            matches++;\n"
 "          }\n"
 "          else\n"
-"          {  \n"
-"            row.style.display = 'none';  \n"
+"          {\n"
+"            row.style.display = 'none';\n"
 "          }\n"
 "        }\n"
 "        i++;\n"
 "      }\n"
 "      document.getElementById(\"Searching\").style.display='none';\n"
 "      if (matches == 0) // no results\n"
-"      {  \n"
-"        document.getElementById(\"NoMatches\").style.display='block';  \n"
+"      {\n"
+"        document.getElementById(\"NoMatches\").style.display='block';\n"
 "      }\n"
 "      else // at least one result\n"
-"      {  \n"
-"        document.getElementById(\"NoMatches\").style.display='none';  \n"
+"      {\n"
+"        document.getElementById(\"NoMatches\").style.display='none';\n"
 "      }\n"
 "      this.lastMatchCount = matches;\n"
 "      return true;\n"
@@ -606,9 +606,9 @@
 "            while (1) // search for last child\n"
 "            {\n"
 "              tmpElem = document.getElementById('Item'+newIndex+'_c'+n);\n"
-"              if (tmpElem) \n"
+"              if (tmpElem)\n"
 "              {\n"
-"                focusItem = tmpElem; \n"
+"                focusItem = tmpElem;\n"
 "              }\n"
 "              else // found it!\n"
 "              {\n"
